@@ -15,6 +15,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import multiprocessing
 import os
 import sys
 
@@ -23,11 +24,11 @@ try:
 except ImportError:
     from Queue import Empty
 
+
 from pybuilder.core import init, use_plugin, task, description
 from pybuilder.utils import execute_command, Timer
 from pybuilder.terminal import print_text_line, print_file_content, print_text
 from pybuilder.plugins.python.test_plugin_helper import ReportsProcessor
-
 from pybuilder.terminal import styled_text, fg, GREEN, MAGENTA, GREY
 
 use_plugin("python.core")
@@ -76,9 +77,8 @@ def run_integration_tests_sequentially(project, logger):
 
 def run_integration_tests_in_parallel(project, logger):
     logger.info("Running integration tests in parallel")
-    import multiprocessing
     tests = multiprocessing.Queue()
-    reports = multiprocessing.Queue()
+    reports = ConsumingQueue()
     reports_dir = prepare_reports_directory(project)
     cpu_scaling_factor = project.get_property(
         'integrationtest_cpu_scaling_factor', 4)
@@ -123,25 +123,19 @@ def run_integration_tests_in_parallel(project, logger):
         pool.append(p)
         p.start()
 
-    test_reports = []
     import time
     while not progress.is_finished:
-        try:  # fail OSX has no sem_getvalue() implementation so no queue size
-            while True:
-                report = reports.get_nowait()
-                test_reports.append(report)
-        except Empty:
-            pass
-        finished_tests_count = len(test_reports)
+        reports.consume_available_items()
+        finished_tests_count = reports.size
         progress.update(finished_tests_count)
         progress.render_to_terminal()
-        time.sleep(.5)
+        time.sleep(1)
 
     progress.mark_as_finished()
 
     total_time.stop()
 
-    return (test_reports, total_time)
+    return (reports.items, total_time)
 
 
 def discover_integration_tests(source_path, suffix=".py"):
@@ -226,6 +220,35 @@ def run_single_test(logger, project, reports_dir, test, output_test_names=True):
     return report_item
 
 
+class ConsumingQueue(object):
+
+    def __init__(self):
+        self._items = []
+        self._queue = multiprocessing.Queue()
+
+    def consume_available_items(self):
+        try:
+            while True:
+                item = self.get_nowait()
+                self._items.append(item)
+        except Empty:
+            pass
+
+    def put(self, *args, **kwargs):
+        return self._queue.put(*args, **kwargs)
+
+    def get_nowait(self, *args, **kwargs):
+        return self._queue.get_nowait(*args, **kwargs)
+
+    @property
+    def items(self):
+        return self._items
+
+    @property
+    def size(self):
+        return len(self.items)
+
+
 class TaskPoolProgress(object):
     """
     Class that renders progress for a set of tasks run in parallel.
@@ -239,23 +262,28 @@ class TaskPoolProgress(object):
     FINISHED_SYMBOL = "-"
     PENDING_SYMBOL = "/"
     WAITING_SYMBOL = "|"
+    PACMAN_FORWARD = "ᗧ"
+    PACMAN_BACKWARD = "ᗤ"
+    PACMAN_CYCLE = [PACMAN_BACKWARD, PACMAN_FORWARD]
 
     def __init__(self, total_tasks_count, workers_count):
         self.total_tasks_count = total_tasks_count
         self.finished_tasks_count = 0
         self.workers_count = workers_count
+        self.pacman_index = 0
 
     def update(self, finished_tasks_count):
         self.finished_tasks_count = finished_tasks_count
 
     def render(self):
+        pacman = self.pacman_symbol
         finished_tests_progress = styled_text(self.FINISHED_SYMBOL * self.finished_tasks_count, fg(GREEN))
-        running_tests_count = self.running_tests_count
-        running_tests_progress = styled_text(self.PENDING_SYMBOL * running_tests_count, fg(MAGENTA))
-        waiting_tests_count = self.waiting_tests_count
-        waiting_tests_progress = styled_text(self.WAITING_SYMBOL * waiting_tests_count, fg(GREY))
+        running_tasks_count = self.running_tasks_count
+        running_tests_progress = styled_text(self.PENDING_SYMBOL * running_tasks_count, fg(MAGENTA))
+        waiting_tasks_count = self.waiting_tasks_count
+        waiting_tasks_progress = styled_text(self.WAITING_SYMBOL * waiting_tasks_count, fg(GREY))
 
-        return "\r[%sᗧ%s%s]" % (finished_tests_progress, running_tests_progress, waiting_tests_progress)
+        return "\r[%s%s%s%s]" % (finished_tests_progress, pacman, running_tests_progress, waiting_tasks_progress)
 
     def render_to_terminal(self):
         if self.can_be_displayed:
@@ -266,15 +294,22 @@ class TaskPoolProgress(object):
             print_text_line()
 
     @property
-    def running_tests_count(self):
+    def pacman_symbol(self):
+        pacman_symbol = self.PACMAN_CYCLE[self.pacman_index]
+        self.pacman_index += 1
+        self.pacman_index = self.pacman_index % len(self.PACMAN_CYCLE)
+        return pacman_symbol
+
+    @property
+    def running_tasks_count(self):
         pending_tasks = (self.total_tasks_count - self.finished_tasks_count)
         if pending_tasks > self.workers_count:
             return self.workers_count
         return pending_tasks
 
     @property
-    def waiting_tests_count(self):
-        return (self.total_tasks_count - self.finished_tasks_count - self.running_tests_count)
+    def waiting_tasks_count(self):
+        return (self.total_tasks_count - self.finished_tasks_count - self.running_tasks_count)
 
     @property
     def is_finished(self):
